@@ -1,10 +1,10 @@
 #
-# $Id: Encode.pm,v 2.25 2008/05/07 20:56:05 dankogai Exp dankogai $
+# $Id: Encode.pm,v 2.27 2009/01/21 22:55:07 dankogai Exp dankogai $
 #
 package Encode;
 use strict;
 use warnings;
-our $VERSION = sprintf "%d.%02d", q$Revision: 2.25 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%02d", q$Revision: 2.27 $ =~ /(\d+)/g;
 sub DEBUG () { 0 }
 use XSLoader ();
 XSLoader::load( __PACKAGE__, $VERSION );
@@ -51,7 +51,14 @@ use Encode::Alias;
 our %Encoding;
 our %ExtModule;
 require Encode::Config;
-eval { require Encode::ConfigLocal };
+#  See
+#  https://bugzilla.redhat.com/show_bug.cgi?id=435505#c2
+#  to find why sig handers inside eval{} are disabled.
+eval {
+    local $SIG{__DIE__};
+    local $SIG{__WARN__};
+    require Encode::ConfigLocal;
+};
 
 sub encodings {
     my $class = shift;
@@ -856,6 +863,8 @@ B<know> that the STRING is well-formed UTF-8.  Returns the previous
 state of the UTF8 flag (so please don't treat the return value as
 indicating success or failure), or C<undef> if STRING is not a string.
 
+This function does not work on tainted values.
+
 =item _utf8_off(STRING)
 
 [INTERNAL] Turns off the UTF8 flag in STRING.  Do not use frivolously.
@@ -863,6 +872,8 @@ Returns the previous state of the UTF8 flag (so please don't treat the
 return value as indicating success or failure), or C<undef> if STRING is
 not a string.
 
+This function does not work on tainted values.
+
 =back
 
 =head1 UTF-8 vs. utf8 vs. UTF8
